@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2006 Zope Corporation and Contributors.
+# Copyright (c) 2006 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -13,13 +13,15 @@
 ##############################################################################
 """Base Components support
 
-$Id: baseregistry.py 107148 2009-12-27 09:03:32Z fafhrd $
 """
 __docformat__ = "reStructuredText"
-from zope.component import globalregistry, interfaces
+from zope.component import globalregistry
+from zope.interface.interfaces import IComponents
+
 
 def BC(components, name):
-    return components.getUtility(interfaces.IComponents, name)
+    return components.getUtility(IComponents, name)
+
 
 class BaseComponents(globalregistry.BaseGlobalComponents):
     """An ``IComponents`` implementation that serves as base for other
@@ -27,7 +29,7 @@ class BaseComponents(globalregistry.BaseGlobalComponents):
 
     def __init__(self, parent, *args, **kw):
         self.__parent__ = parent
-        super(BaseComponents, self).__init__(*args, **kw)
+        super().__init__(*args, **kw)
 
     def __reduce__(self):
         # Global site managers are pickled as global objects
