@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2006 Zope Corporation and Contributors.
+# Copyright (c) 2006 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -11,30 +11,31 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""Base Components test setup
-
-$Id: testdoc.py 107148 2009-12-27 09:03:32Z fafhrd $
-"""
-__docformat__ = "reStructuredText"
+"""Base Components test setup."""
 import doctest
 import unittest
-from zope.app.testing import placelesssetup, setup
+
+from zope.testing import module
+from zope.testing import renormalizing
+from zope.testing.cleanup import CleanUp
+
 
 def setUp(test):
-    placelesssetup.setUp(test)
-    setup.setUpTestAsModule(test, name='README')
+    CleanUp().setUp()
+    module.setUp(test, name='README')
+
 
 def tearDown(test):
-    placelesssetup.tearDown(test)
+    module.tearDown(test, name='README')
+    CleanUp().tearDown()
+
 
 def test_suite():
     return unittest.TestSuite((
-            doctest.DocFileSuite(
-                '../README.txt',
-                setUp=setUp, tearDown=tearDown,
-                optionflags=doctest.NORMALIZE_WHITESPACE|doctest.ELLIPSIS,
-                ),
-            ))
-
-if __name__ == '__main__':
-    unittest.main(defaultTest='test_suite')
+        doctest.DocFileSuite(
+            '../README.rst',
+            setUp=setUp, tearDown=tearDown,
+            optionflags=doctest.NORMALIZE_WHITESPACE | doctest.ELLIPSIS,
+            checker=renormalizing.RENormalizing(),
+        ),
+    ))
