@@ -13,14 +13,13 @@
 ##############################################################################
 """ZCML Implementation to populate base registries.
 
-$Id: zcml.py 118007 2010-10-28 13:39:39Z adamg $
 """
 __docformat__ = "reStructuredText"
-import zope.interface
 import zope.component.globalregistry
 import zope.component.hooks
 import zope.configuration.config
 import zope.configuration.fields
+import zope.interface
 from zope.configuration.exceptions import ConfigurationError
 
 
@@ -28,12 +27,12 @@ class IRegisterInDirective(zope.interface.Interface):
     """Use the specified registry for registering the contained components."""
 
     registry = zope.configuration.fields.GlobalObject(
-        title=u"Registry",
-        description=u"Python path to the registry to use.",
+        title="Registry",
+        description="Python path to the registry to use.",
         required=True)
 
 
-class ActionsProxy(object):
+class ActionsProxy:
     """A proxy object for the actions list to decorate the incoming actions."""
 
     original = None
@@ -43,18 +42,28 @@ class ActionsProxy(object):
         self.original = original
         self.registry = registry
 
-    def __decorate(self, item):
-        discriminator = None
-        if item[0] is not None:
-            discriminator = (self.registry, item[0])
-        return (discriminator,) + item[1:]
+    def __decorate(self, action):
+        # handle action dict
+        # (was a tuple before 2.0, see zope.configuration 3.8 for changes)
+        # discriminator is a tuple like:
+        # ('utility',
+        #  <InterfaceClass zope.component.interfaces.IFactory>,
+        #  'my.package.interfaces.IMyInterface')
+        # in the sample above this means we need to prepend our registry
+        # to the existing discriminator.
+        discriminator = action.get('discriminator', None)
+        if discriminator is not None:
+            # replace the first part from the existing descriminator tuple
+            # with our registry
+            action['discriminator'] = (self.registry, discriminator)
+        return action
 
     def __setitem__(self, i, item):
-        self.original.__setitem__(i, self.__decorate(item))
-
-    def __setslice__(self, i, j, other):
-        other = [self.__decorate(item) for item in other]
-        self.original.__setslice__(i, j, other)
+        if isinstance(i, slice):
+            item = [self.__decorate(x) for x in item]
+        else:
+            item = self.__decorate(item)
+        self.original.__setitem__(i, item)
 
     def __iadd__(self, other):
         other = [self.__decorate(item) for item in other]
@@ -70,11 +79,14 @@ class ActionsProxy(object):
         other = [self.__decorate(item) for item in other]
         self.original.extend(other)
 
+    def __len__(self):
+        return len(self.original)
+
     def __getattr__(self, name):
         return getattr(self.original, name)
 
 
-class FakeBaseRegistrySite(object):
+class FakeBaseRegistrySite:
     """This a minimal fake Site, the only responsibility it has
     is to store our registry as a SiteManager and return it later.
     This is needed to fool siteinfo via setSite, zope.component.zcml.handler
@@ -86,11 +98,13 @@ class FakeBaseRegistrySite(object):
     def getSiteManager(self):
         return self.sm
 
+
 def setActiveRegistry(context, registry):
     context.original = zope.component.hooks.getSite()
     fakeSite = FakeBaseRegistrySite(registry)
     zope.component.hooks.setSite(fakeSite)
 
+
 def resetOriginalRegistry(context):
     zope.component.hooks.setSite(context.original)
 
@@ -98,7 +112,7 @@ def resetOriginalRegistry(context):
 class RegisterIn(zope.configuration.config.GroupingContextDecorator):
 
     # Marker that this directive has been used in the path
-    registryChanged=True
+    registryChanged = True
 
     # Storage for the original site
     original = None
@@ -108,7 +122,7 @@ class RegisterIn(zope.configuration.config.GroupingContextDecorator):
             raise ConfigurationError(
                 'Nested ``registerIn`` directives are not permitted.')
 
-        super(RegisterIn, self).__init__(context, **kw)
+        super().__init__(context, **kw)
         self.registry = registry
         self.actions = ActionsProxy(context.actions, registry)
 
@@ -117,11 +131,11 @@ class RegisterIn(zope.configuration.config.GroupingContextDecorator):
             discriminator=None,
             callable=setActiveRegistry,
             args=(self, self.registry)
-            )
+        )
 
     def after(self):
         self.context.action(
             discriminator=None,
             callable=resetOriginalRegistry,
             args=(self,)
-            )
+        )
